@@ -52,6 +52,8 @@ class Group(models.Model):
 if not hasattr(Permission, 'label'):
     label = models.CharField(db_column='label', max_length=255, blank=True, null=False)
     label.contribute_to_class(Permission, 'label')
+    sub_label = models.CharField(db_column='sub_label', max_length=255, blank=True, null=False)
+    sub_label.contribute_to_class(Permission, 'sub_label')
     
     
     
\ No newline at end of file
